geomodels package
=================

.. automodule:: geomodels
   :members:
   :undoc-members:
   :show-inheritance:

Geoid model
-----------

.. autoclass:: GeoidModel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: EHeightConvDir
   :members:
   :undoc-members:
   :show-inheritance:

Gravity model
-------------

.. autoclass:: GravityModel
   :members:
   :undoc-members:
   :show-inheritance:

Magnetic filed model
--------------------

.. autoclass:: MagneticFieldModel
   :members:
   :undoc-members:
   :show-inheritance:

Functions
---------

.. autofunction:: lib_version_info

.. autofunction:: lib_version_str

.. autofunction:: test

Sub-modules
-----------

.. toctree::
   :maxdepth: 4

   geomodels.cli
   geomodels.data
   geomodels.error
   geomodels.wmmf
